@@ -2,6 +2,8 @@
 import datetime
 from enum import Enum
 
+import pandas as pd
+
 
 class BaseModel:
     """ Base model """
@@ -10,7 +12,7 @@ class BaseModel:
         self.id = kwargs("id", None)
 
     def from_datetime(self, date):
-        if not date:
+        if pd.isna(date):
             return None
         elif isinstance(date, datetime.datetime):
             return date.isoformat()
